CCL: /home/chisarie/Documents/lsst_ccl/CCL/src/ccl_error.c File Reference

CCL

Functions
ccl_error.c File Reference
`#include "ccl_core.h"`
`#include "ccl_error.h"`
`#include "math.h"`
`#include "stdio.h"`
`#include "stdlib.h"`

## Functions
void | ccl_set_error_policy (CCLErrorPolicy error_policy)
void | ccl_raise_exception (int err, char *msg)
void | ccl_check_status (ccl_cosmology *cosmo, int *status)
void | ccl_check_status_nocosmo (int *status)

## Function Documentation

## ◆ ccl_check_status()

void ccl_check_status | ( | ccl_cosmology * | cosmo,
|  | int * | status
| ) |  |

Check the error status Given a status, check if any errors have occurred, based on the CCL_ERRORs defined so far.

Returns
  void

## ◆ ccl_check_status_nocosmo()

void ccl_check_status_nocosmo | ( | int * | status | ) |

Check the error status - no cosmology Given a status, check if any errors have occurred, based on the CCL_ERRORs defined so far.

Returns
  void

## ◆ ccl_raise_exception()

void ccl_raise_exception | ( | int | err,
|  | char * | msg
| ) |  |

Raise an exception Given a status, give an error message.

Returns
  void

## ◆ ccl_set_error_policy()

void ccl_set_error_policy | ( | CCLErrorPolicy | error_policy | ) |

Set the error policy error_policy the error policy

Returns
  void